# FacilityPython

Base class for Python [FacilityApi](https://facilityapi.github.io/) clients generated by [fsdgenpython](https://github.com/FacilityApi/FacilityPython).

All you need to do is install it and then import your generated client code.

## Contents

### `facility.py`

Imported by generated client code. Defines base classes such as `DTO`, `Result`, `OAuthSettings`, and `ClientBase`.
